import { API_URL } from '$env/static/private';
import { redirect } from '@sveltejs/kit';
import type { PageServerLoad } from './$types';

import type { LeaderboardEvent } from '$lib/types';
import { handleRedirect } from '$lib/utils';

export const load: PageServerLoad = async ({ url, locals: { user }, fetch, cookies, params: { chapterId } }) => {

	if (!user) redirect(302, handleRedirect('login', url));

	if (!chapterId) redirect(302, '/');

	const session = cookies.get('session');

	const res = await fetch(`${API_URL}/leaderboard/${chapterId}`, {
		headers: {
			Authorization: `Bearer ${session}`
		}
	});

	if (!res.ok) return {
		leaderboard: []
	}

	const leaderboard = (await res.json()) as LeaderboardEvent;

	if (!leaderboard) return {
		leaderboard: []
	}

	return {
		title: "Classement",
		leaderboard
	};
};
